# Copyright 2014, Red Hat, Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Authors:
#    Josef Skladanka <jskladan@redhat.com>

from vault import db
from flask.ext.login import UserMixin
from werkzeug.security import generate_password_hash, check_password_hash

USERNAME_OIDC_GROUP_PREFIX = u"FAS GROUP: "

class UserCreationException(ValueError):
    pass

class User(db.Model, UserMixin):

    id = db.Column(db.Integer, primary_key=True)
    username = db.Column(db.String(80), unique=True)
    pw_hash = db.Column(db.String(120), unique=False)
    role = db.Column(db.String(10))
    bucket_roles = tuple()
    bucket_group_roles = tuple()

    def __init__(self, username, password, role='user'):
        # FIXME - find a better way of doing this in the future
        # probably by separating the groups into standalone table
        # this is OK for now.
        if username.startswith(USERNAME_OIDC_GROUP_PREFIX) and role != 'oidc_group':
            raise UserCreationException("Username can not start with %s", USERNAME_OIDC_GROUP_PREFIX)
        self.username = username
        self.pw_hash = None
        if password:
            self.set_password(password)
        self.role = role

    def __repr__(self):
        return '<User %r - %r>' % (self.username, self.role)

    def set_password(self, password):
        self.pw_hash = generate_password_hash(password)

    def check_password(self, password):
        if self.pw_hash is None or self.role == 'oidc_group':
            return False
        return check_password_hash(self.pw_hash, password)
